Crate opentelemetry_traceable

Crate opentelemetry_traceable 

Dynamic, per-function tracing on top of opentelemetry-rust.

Annotate any fn/async fn with #[traceable], then create an instrumentation::Instrumentation and toggle tracing for those functions at runtime.

Modules

instrumentation
An Instrumentation is an intance of a tracing configuration that defines which (of the traceable functions) are enabled for tracing. Each instrumentation maps to one tracer provider (and exporter), so that different exporting configuration can be assigned to different instrumentations.
registry
Link-time-collected registry of every #[traceable] function.
selector
Selecting #[traceable] functions by name/key, using exact match, or * pattern match.

Attribute Macros

traceable
Marks a fn or async fn as a candidate for tracing.